@@ -2,7 +2,7 @@
 #
 # Simple r2u helper frontend
 #
-# Copyright (C) 2022 - 2024  Dirk Eddelbuettel
+# Copyright (C) 2022 - 2025  Dirk Eddelbuettel
 #
 # Released under GPL (>= 2)
 
@@ -11,7 +11,7 @@ library(docopt)
 doc <- "Usage: r2u.r [--release DIST] [--debug] [--verbose] [--force] [--xvfb] [--bioc] [--suffix SUF] [--debver DBV] [--plusdfsg] [--uncache] [--dryrun] [--compile] [--help] CMD ...
 
 Options:
--r --release DIST   release distribution to use, one of 'focal', 'jammy', 'noble' [default: jammy]
+-r --release DIST   release distribution to use, one of 'focal', 'jammy', 'noble' [default: noble]
 -d --debug          boolean flag for extra debugging
 -v --verbose        boolean flag for verbose operation
 -f --force          boolean flag to force a build
@@ -62,14 +62,17 @@ if (is.finite(match(opt$CMD, "build"))) {
                          opt$dryrun)
 
 } else if (is.finite(match(opt$CMD, "last"))) {
-    D <- RcppSimdJson::fload("https://p3m.dev/__api__/sources/1/transactions")
+    # NB now dead too:  D <- RcppSimdJson::fload("https://p3m.dev/__api__/sources/1/transactions")
     #ts <- anytime::utctime(D[1,"completed"])
     #dh <- as.numeric(difftime(Sys.time(), ts, units="hours"))
     #un <- "days"
     #if (dh <= 3) un <- "mins" else if (dh < 25) un <- "hours"
     #cat("P3M/PPM/RSPM last updated", format(round(difftime(Sys.time(), ts, units=un),1)), "ago\n")
     ## no longer includes hours :-/
-    ld <- anytime::utcdate(D[1,"completed"])
+    #ld <- anytime::utcdate(D[1,"completed"])
+    ## also:  hit given yyyy-mm-dd in eg https://packagemanager.posit.co/cran/2025-04-22/src/contrib/PACKAGES
+    ##        and then check success / failure -- might be lighter than downloading the whole blob
+    ld <- as.Date(max(RcppSimdJson::fload("https://p3m.dev/__api__/repos/cran/transaction-dates")$alias))
     cat("P3M/PPM/RSPM last updated", as.integer(Sys.Date()) - as.integer(ld), "days ago on", format(ld), "\n")
 
 } else if (is.finite(match(opt$CMD, "count"))) {
